{-# OPTIONS_HADDOCK hide #-}
#if __GLASGOW_HASKELL__ >= 701
{-# LANGUAGE Safe #-}
#endif
-- |
-- Module      : Data.ByteString.Fusion
-- License     : BSD-style
-- Maintainer  : dons@cse.unsw.edu.au
-- Stability   : experimental
-- Portability : portable
--
-- Stream fusion for ByteStrings.
--
-- See the paper /Stream Fusion: From Lists to Streams to Nothing at All/,
-- Coutts, Leshchinskiy and Stewart, 2007.  
--

module Data.ByteString.Fusion (

    -- A place holder for Stream Fusion

  ) where


